@@ -10,7 +10,7 @@ use File::HomeDir;
 use Log::Any qw/$log/;
 use Path::Tiny qw/path rootdir cwd/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 our $pager;
 
 sub DBVERSION { 1 }
@@ -797,15 +797,95 @@ sub get_node {
     return $self->err( 'TopicNotFound', "$kind not found: $token" );
 }
 
+sub save_new_work {
+    my $self = shift;
+
+    state $have_time_piece   = require Time::Piece;
+    state $have_time_seconds = require Time::Seconds;
+    state $have_coalesce_qv  = DBIx::ThinSQL->import(qw/ coalesce qv /);
+
+    # Some error in Time::Piece exposed if gmtime is passed a
+    # Time::Seconds object so make it a plain scalar for now and open
+    # a bug at some point... in my spare time :-(
+
+    my $args = { offset => ${ Time::Piece->new->tzoffset }, @_ };
+
+    # Prefer not to insert work entries that cross midnight so split
+    # the request up accordingly.
+    my $start = Time::Piece->gmtime( $args->{start} + $args->{offset} );
+    my $stop  = Time::Piece->gmtime( $args->{stop} + $args->{offset} );
+
+    until ( $start->ymd eq $stop->ymd ) {
+        my $day_end =
+          Time::Piece->strptime( $start->ymd, '%Y-%m-%d' ) +
+          Time::Seconds->ONE_DAY - 1;
+
+        $self->dbw->xdo(
+            insert_into => [
+                'func_new_work', qw/
+                  change_id
+                  node_id
+                  offset
+                  start
+                  stop
+                  comment
+                  bill
+                  /
+            ],
+            select => [
+                qv( $args->{change_id} ),
+                qv( $args->{node_id} ),
+                qv( $args->{offset} ),
+                qv( ( $start - $args->{offset} )->epoch ),
+                qv( ( $day_end - $args->{offset} )->epoch ),
+                qv( $args->{comment} ),
+                coalesce( qv( $args->{bill} ), 'n.bill' ),
+            ],
+            from  => 'nodes n',
+            where => { 'n.id' => $args->{node_id} },
+        );
+
+        $start = $day_end + 1;
+    }
+
+    $self->dbw->xdo(
+        insert_into => [
+            'func_new_work', qw/
+              change_id
+              node_id
+              offset
+              start
+              stop
+              comment
+              bill
+              /
+        ],
+        select => [
+            qv( $args->{change_id} ),
+            qv( $args->{node_id} ),
+            qv( $args->{offset} ),
+            qv( ( $start - $args->{offset} )->epoch ),
+            qv( ( $stop - $args->{offset} )->epoch ),
+            qv( $args->{comment} ),
+            coalesce( qv( $args->{bill} ), 'n.bill' ),
+        ],
+        from  => 'nodes n',
+        where => { 'n.id' => $args->{node_id} },
+    );
+}
+
 sub current_work {
     my $self = shift;
     return $self->dbw->xhashref(
         select => [
             'n.id AS node_id',
-            'n.kind AS kind',
+            'COALESCE(t.tkind,n.kind) AS kind',
             'n.path AS path',
             'wb.start AS start',
-            'wb.billable AS billable',
+            time . ' AS stop',
+            'wb.offset AS offset',
+            'wb.bill AS bill',
+            'wb.comment AS comment',
             'COALESCE(t.title,"") AS title',
         ],
         from       => 'work_buffers wb',
@@ -813,7 +893,6 @@ sub current_work {
         on         => 'n.id = wb.node_id',
         left_join  => 'topics t',
         on         => 't.id = n.id',
-        where      => { 'wb.stop' => undef },
     );
 }
 
@@ -822,29 +901,25 @@ sub start_work {
     my $args = {@_};
     my $dbw  = $self->dbw;
 
-    if ( $args->{save} ) {
-        my $ref = $dbw->xhashref(
-            select => '*',
-            from   => 'work_buffers',
-            where  => { stop => undef },
-        );
-
-        if ($ref) {
-            $self->stop_work( stop => $args->{start} );
-            $self->work_buffer($ref);
-        }
-    }
+    state $have_coalesce_qv = DBIx::ThinSQL->import(qw/ coalesce qv /);
 
     return $self->dbw->xdo(
-        insert_into => 'work_buffers',
-        values      => {
-            node_id       => $args->{node_id},
-            start         => $args->{start},
-            start_comment => $args->{start_comment},
-            stop          => $args->{stop},
-            stop_comment  => $args->{stop_comment},
-            billable      => $args->{billable},
-        },
+        insert_into => [
+            'work_buffers', qw/
+              node_id
+              start
+              comment
+              bill
+              /
+        ],
+        select => [
+            qv( $args->{node_id} ),
+            qv( $args->{start} // time ),
+            qv( $args->{comment} ),
+            coalesce( qv( $args->{bill} ), 'n.bill' ),
+        ],
+        from  => 'nodes n',
+        where => { 'n.id' => $args->{node_id} },
     );
 }
 
@@ -852,114 +927,52 @@ sub stop_work {
     my $self = shift;
     my $args = {@_};
     my $dbw  = $self->dbw;
-    my $ref  = $dbw->xhashref(
-        select => '*',
-        from   => 'work_buffers',
-        where  => { stop => undef },
+    my $work = $self->current_work || return;
+
+    $args->{change_id} = $self->new_change;
+
+    $self->save_new_work(
+        change_id => $args->{change_id},
+        node_id   => $work->{node_id},
+        start     => $work->{start},
+        stop      => $args->{stop} // time,
+        offset    => $work->{offset},
+        comment   => $args->{comment} // $work->{comment},
+        bill      => $args->{bill} // $work->{bill},
     );
 
-    $self->work_buffer($ref) if $ref and $args->{save};
-
-    if ($ref) {
-
-        # We are currently working something so we need to check if the
-        # start time is yesterday (for some kind of yesterday) and
-        # insert (multiple) work buffers that don't cross the midnight
-        # boundary.
-
-        # The trick is that the calculation has to be done in the
-        # timezone of the $ref work buffer. The code below is probably
-        # broken if the current timezone offste is different to
-        # $ref->{offset}.
-
-        state $have_time_piece   = require Time::Piece;
-        state $have_time_seconds = require Time::Seconds;
-
-        my $stop_ymd =
-          Time::Piece->gmtime( $args->{stop} + $ref->{offset} )->ymd;
-        my $boundary =
-          Time::Piece->strptime(
-            Time::Piece->gmtime( $ref->{start} + $ref->{offset} )->ymd,
-            '%Y-%m-%d' ) +
-          Time::Seconds->ONE_DAY - 1;
-
-        until ( $boundary->ymd eq $stop_ymd ) {
-            $dbw->xdo(
-                update => 'work_buffers',
-                set    => { stop => $boundary->epoch - $ref->{offset} },
-                where  => { stop => undef },
-            );
-
-            $self->dbw->xdo(
-                insert_into => 'work_buffers',
-                values      => {
-                    node_id       => $ref->{node_id},
-                    start         => ( $boundary - $ref->{offset} + 1 )->epoch,
-                    start_comment => $ref->{start_comment},
-                    stop          => undef,
-                    stop_comment  => $ref->{stop_comment},
-                    billable      => $ref->{billable},
-                },
-            );
-
-            $boundary = $boundary + Time::Seconds->ONE_DAY;
-        }
-    }
-
-    $dbw->xdo(
-        update => 'work_buffers',
-        set    => {
-            stop         => $args->{stop},
-            stop_comment => $args->{stop_comment},
-        },
-        where => { stop => undef },
+    $self->end_change(
+        id               => $args->{change_id},
+        action_format    => "work $work->{kind} %s",
+        action_node_id_1 => $work->{node_id},
+        message          => 'stuff',                   #$opts->{message},
     );
 
-    if ( $args->{restore} and my $saved = $self->work_buffer ) {
-
-        $self->start_work(
-            node_id       => $saved->{node_id},
-            offset        => $saved->{offset},
-            start         => $args->{stop},
-            start_comment => $saved->{start_comment},
-            billable      => $saved->{billable},
-        );
-
-        $self->work_buffer(undef);
-    }
+    $dbw->xdo( delete_from => 'work_buffers', );
 }
 
-sub record_work {
+sub pause_work {
     my $self = shift;
-    my $args = {@_};
 
-    $self->dbw->xdo(
-        insert_into => [
-            'func_new_work', qw/change_id node_id offset start stop
-              start_comment stop_comment/
-        ],
-        select => [
-            $args->{change_id}, $args->{node_id},
-            'wb.offset',        'wb.start',
-            'wb.stop',          'wb.start_comment',
-            'wb.stop_comment',
-        ],
-        from  => 'work_buffers wb',
-        where => {
-            'wb.node_id'  => $args->{node_id},
-            'wb.billable' => 1,
-            'wb.stop !'   => undef,
-        },
+    $self->work_buffer( $self->current_work ) || return;
+    print "Pausing work on ...\n";
+    $self->stop_work;
+}
+
+sub resume_work {
+    my $self  = shift;
+    my $args  = {@_};
+    my $saved = $self->work_buffer || return;
+
+    print "Resuming work on ...\n";
+    $self->start_work(
+        node_id => $saved->{node_id},
+        start   => time,
+        comment => $saved->{comment},
+        bill    => $saved->{bill},
     );
 
-    $self->dbw->xdo(
-        delete_from => 'work_buffers',
-        where       => {
-            'node_id'  => $args->{node_id},
-            'billable' => 1,
-            'stop !'   => undef,
-        }
-    );
+    $self->work_buffer(undef);
 }
 
 sub new_change {
@@ -1143,7 +1156,7 @@ App::bif - A base class for App::bif::* commands
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
@@ -1413,7 +1426,7 @@ Returns a hashref representing the currently open work buffer:
 
 =item * start
 
-=item * billable
+=item * bill
 
 =item * title - value from topics.title if the node kind is a topic
 
@@ -1429,13 +1442,11 @@ Creates a new entry in the work_buffers table.
 
 =item * start
 
-=item * start_comment
-
 =item * stop
 
-=item * stop_comment
+=item * comment
 
-=item * billable
+=item * bill
 
 =item * save
 
@@ -1450,14 +1461,24 @@ table if one exists.
 
 =item * stop
 
-=item * stop_comment
-
-=item * restore
-
-=item * save
-
 =back
 
+=item pause_work()
+
+Saves the item currently in the work buffer to
+C<$App::bif::work_buffer> and then calls stop_work() on it.  The saved
+work item can later be restarted with a call to resume_work().
+
+=item resume_work()
+
+Puts the work item previously saved into C<$App::bif::work_buffer> by
+pause_work() back into the work buffer with a new start time of "now."
+
+=item save_new_work(%opts)
+
+Calls C<func_new_work> taking into account work that crosses the
+midnight boundary.
+
 =item new_change( %args ) -> Int
 
 Creates a new row in the changes table according to the content of
