@@ -1,6 +1,6 @@
 package App::bif::OptArgs;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 
 package    # do a little hiding
   App::bif;
@@ -124,6 +124,12 @@ opt author => (
     hidden  => 1,
 );
 
+opt bill => (
+    isa     => 'Bool',
+    comment => 'Record work effort in the timesheet',
+    hidden  => 1,
+);
+
 opt email => (
     isa     => 'Str',
     comment => 'Email',
@@ -631,6 +637,12 @@ arg date => (
     comment => 'timesheet start date',
 );
 
+opt bill => (
+    isa     => 'Bool',
+    alias   => 'b',
+    comment => 'only show billable work',
+);
+
 opt identity => (
     isa     => 'Str',
     alias   => 'i',
@@ -1453,11 +1465,10 @@ opt force => (
     comment => 'force work when working something else',
 );
 
-opt not_billable => (
+opt bill => (
     isa     => 'Bool',
     alias   => 'B',
-    default => 0,
-    comment => 'do not record this work on next update',
+    comment => 'do (or do not) record this work in timesheet',
 );
 
 1;
@@ -1472,7 +1483,7 @@ App::bif::OptArgs - bif command argument & option definitions
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
