@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -21,25 +21,11 @@ sub run {
     $dbw->txn(
         sub {
             if ( $info->{default_hub_id} ) {
-                $self->start_work(
-                    start         => time,
-                    start_comment => "drop project $info->{path} (shallow)",
-                    billable      => 0,
-                    save          => 1,
-                );
-
                 $self->drop_shallow($info);
 
                 print "Project dropped: $info->{path} (shallow)\n";
             }
             else {
-                $self->start_work(
-                    start         => time,
-                    start_comment => "drop project $info->{path}",
-                    billable      => 0,
-                    save          => 1,
-                );
-
                 $dbw->xdo(
                     delete_from => 'projects',
                     where       => { id => $info->{id} },
@@ -47,11 +33,6 @@ sub run {
 
                 print "Project dropped: $info->{path})\n";
             }
-
-            $self->stop_work(
-                stop    => time,
-                restore => 1,
-            );
         }
     );
 
@@ -130,7 +111,7 @@ bif-drop-project - remove an project from the repository
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
