@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Path::Tiny qw/cwd path/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub init_user_repo {
@@ -33,8 +33,7 @@ sub init_user_repo {
                 },
             );
 
-            $self->dispatch( 'App::bif::new::identity',
-                opts => { self => 1, } );
+            $self->dispatch( 'App::bif::new::identity', opts => { self => 1 } );
         },
     );
 }
@@ -114,7 +113,7 @@ bif-init - initialize a new bif repository
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
