@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -15,10 +15,7 @@ sub run {
     $dbw->txn(
         sub {
             my $start = time;
-            $self->stop_work(
-                stop => $start,
-                save => 1,
-            );
+            $self->pause_work;
 
             $opts->{name} ||= prompt( 'Name:', '' )
               || return $self->err( 'NameRequired', 'name is required' );
@@ -39,21 +36,13 @@ sub run {
                 values      => { key => 'local', hub_id => $opts->{id} },
             ) if $opts->{default};
 
-            $self->start_work(
-                node_id       => $opts->{id},
-                start         => $start,
-                start_comment => "new hub",
-                billable      => 1,
-            );
-
-            $self->stop_work(
-                stop    => time,
-                restore => 1,
-            );
-
-            $self->record_work(
+            $self->save_new_work(
+                change_id => $opts->{change_id},
                 node_id   => $opts->{id},
-                change_id => $opts->{change_id}
+                start     => $start,
+                stop      => time,
+                comment   => "new hub",
+                bill      => 1,
             );
 
             $self->end_change(
@@ -65,6 +54,7 @@ sub run {
 
             printf( "Hub created: %s\n", $opts->{name} );
 
+            $self->resume_work;
         }
     );
 
@@ -83,6 +73,7 @@ sub new_hub {
             id        => $opts->{id},
             name      => $opts->{name},
             title     => $opts->{title},
+            bill      => $opts->{bill} // 1,
         }
     )->new_project;
 
@@ -92,6 +83,7 @@ sub new_hub {
             change_id => $opts->{change_id},
             id        => $opts->{id},
             location  => $opts->{location},
+            bill      => $opts->{bill} // 1,
         },
     );
 
@@ -109,7 +101,7 @@ bif-new-hub - create a new hub in the repository
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
