@@ -7,7 +7,7 @@ use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 use Path::Tiny qw/path/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -18,10 +18,7 @@ sub run {
     $dbw->txn(
         sub {
             my $start = time;
-            $self->stop_work(
-                stop => $start,
-                save => 1,
-            );
+            $self->pause_work;
 
             my $name   = '';
             my $email  = '';
@@ -82,6 +79,7 @@ sub run {
                     name      => $opts->{name},
                     shortname => $opts->{shortname},
                     self      => $opts->{self},
+                    bill      => $opts->{bill} // 0,
                 },
             );
 
@@ -93,6 +91,7 @@ sub run {
                     identity_id => $opts->{id},
                     method      => $opts->{method},
                     mvalue      => bv( $opts->{value}, DBI::SQL_VARCHAR ),
+                    bill        => $opts->{bill} // 0,
                 },
             );
 
@@ -106,21 +105,13 @@ sub run {
                 },
             );
 
-            $self->start_work(
-                node_id       => $opts->{id},
-                start         => $start,
-                start_comment => "new identity",
-                billable      => 1,
-            );
-
-            $self->stop_work(
-                stop    => time,
-                restore => 1,
-            );
-
-            $self->record_work(
+            $self->save_new_work(
+                change_id => $opts->{change_id},
                 node_id   => $opts->{id},
-                change_id => $opts->{change_id}
+                start     => $start,
+                stop      => time,
+                comment   => "new identity",
+                bill      => 1,
             );
 
             $self->end_change(
@@ -130,6 +121,8 @@ sub run {
                   . "$opts->{name} ($opts->{shortname})",
                 action_node_id_1 => $opts->{id},
             );
+
+            $self->resume_work;
         }
     );
 
@@ -147,7 +140,7 @@ bif-new-identity - create a new identity in the repository
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
