@@ -5,7 +5,7 @@ use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 use DBIx::ThinSQL qw/ case qv sq/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub dup {
@@ -46,6 +46,7 @@ sub dup {
                     parent_id => $opts->{parent_id},
                     name      => $opts->{name},
                     title     => $opts->{title},
+                    bill      => $opts->{bill} // 1,
                 },
             );
 
@@ -89,6 +90,7 @@ sub dup {
                         project_id => $opts->{id},
                         status     => $status->{status},
                         rank       => $status->{rank},
+                        bill       => $opts->{bill} // 1,
                     }
                 );
             }
@@ -105,13 +107,14 @@ sub dup {
             $dbw->xdo(
                 insert_into => [
                     'func_new_topic_status',
-                    qw/change_id id project_id tkind status rank def/,
+                    qw/change_id id project_id tkind status rank def
+                      bill/,
                 ],
                 select => [
                     qv( $opts->{change_id} ), 'nextval("nodes")',
                     qv( $opts->{id} ),        'ts.tkind',
                     'ts.status',              'ts.rank',
-                    'ts.def',
+                    'ts.def', qv( $opts->{bill} // 1 ),
                 ],
                 from     => 'topic_status ts',
                 where    => { 'ts.project_id' => $dup_pinfo->{id} },
@@ -147,6 +150,7 @@ sub new_project {
             parent_id => $opts->{parent_id},
             name      => $opts->{name},
             title     => $opts->{title},
+            bill      => $opts->{bill} // 1,
         },
     );
 
@@ -176,6 +180,7 @@ sub new_project {
                 project_id => $opts->{id},
                 status     => $status->{status},
                 rank       => $status->{rank},
+                bill       => $opts->{bill} // 1,
             }
         );
     }
@@ -211,7 +216,7 @@ sub new_project {
     $dbw->xdo(
         insert_into => [
             'func_new_topic_status',
-            qw/change_id id project_id tkind status rank def/,
+            qw/change_id id project_id tkind status rank def bill/,
         ],
         select => [
             qv( $opts->{change_id} ),
@@ -224,7 +229,8 @@ sub new_project {
                 when => 'ds.def',
                 then => 1,
                 else => 0,
-            )->as('def'),
+              )->as('def'),
+            qv( $opts->{bill} // 1 ),
         ],
         from     => 'default_status ds',
         where    => { 'ds.kind !' => [ 'project', 'hub' ] },
@@ -239,11 +245,13 @@ sub run {
 
     $dbw->txn(
         sub {
+            $self->pause_work;
             my $start = time;
-            $self->stop_work(
-                stop => $start,
-                save => 1,
-            );
+
+            #            $self->stop_work(
+            #                stop => $start,
+            #                save => 1,
+            #            );
 
             $opts->{path} ||= prompt( 'Path:', '' )
               || return $self->err( 'ProjectPathRequired',
@@ -295,36 +303,27 @@ sub run {
                 'project title is required' );
 
             $opts->{message} ||= $self->prompt_edit( opts => $self );
-            $opts->{lang}    ||= 'en';
-            $opts->{id}      ||= $dbw->nextval('nodes');
+            $opts->{lang} ||= 'en';
             $opts->{change_id} ||= $self->new_change;
+            $opts->{id} ||= $dbw->nextval('nodes');
 
             $self->new_project;
 
-            $self->start_work(
-                node_id       => $opts->{id},
-                start         => $start,
-                start_comment => "new project",
-                billable      => 1,
-            );
-
-            $self->stop_work(
-                stop    => time,
-                restore => 1,
-            );
-
-            $self->record_work(
+            $self->save_new_work(
+                bill => $opts->{bill} // 1,
+                change_id => $opts->{change_id},
                 node_id   => $opts->{id},
-                change_id => $opts->{change_id}
+                start     => $start,
+                stop      => time,
             );
 
             $self->end_change(
-                id               => $opts->{change_id},
-                message          => $opts->{message},
-                action_format    => "new project $opts->{path} (%s)",
-                action_node_id_1 => $opts->{id},
+                id            => $opts->{change_id},
+                message       => $opts->{message},
+                action_format => "new project $opts->{path}",
             );
 
+            $self->resume_work;
         }
     );
 
@@ -342,7 +341,7 @@ bif-new-project - create a new project
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
