@@ -9,7 +9,7 @@ use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 use Path::Tiny;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -66,8 +66,6 @@ sub run {
         eval {
             $dbw->txn(
                 sub {
-                    my $start = time;
-
                     my ( $status, $ref ) = $client->pull_hub;
 
                     print "\n";
@@ -80,14 +78,6 @@ sub run {
                         return $status;
                     }
 
-                    $self->start_work(
-                        node_id       => $ref->[0],
-                        start         => $start,
-                        start_comment => 'pull hub',
-                        stop          => time,
-                        billable      => 0,
-                    );
-
                     $dbw->xdo(
                         insert_or_replace_into =>
                           [ 'bifkv', qw/key change_id change_id2/ ],
@@ -127,7 +117,7 @@ bif-pull-hub -  import project lists from a remote repository
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
