@@ -8,7 +8,7 @@ use Coro;
 use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -45,8 +45,6 @@ sub run {
         eval {
             $dbw->txn(
                 sub {
-                    my $start = time;
-
                     $|++;
                     my $status = $client->bootstrap_identity;
 
@@ -73,14 +71,6 @@ sub run {
                         where      => { key => 'self' },
                     );
 
-                    $self->start_work(
-                        node_id       => $iid,
-                        start         => $start,
-                        start_comment => 'pull identity',
-                        stop          => time,
-                        billable      => 0,
-                    );
-
                     print "\n";
                 }
             );
@@ -111,7 +101,7 @@ bif-pull-identity - import an identity from a repository
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
