@@ -7,7 +7,7 @@ use Bif::Sync::Client;
 use Coro;
 use DBIx::ThinSQL qw/qv sq/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -61,8 +61,6 @@ sub run {
         eval {
             $dbw->txn(
                 sub {
-                    my $start = time;
-
                     $dbw->xdo(
                         update => 'projects',
                         set    => 'local = 1',
@@ -80,14 +78,6 @@ sub run {
                         },
                     );
 
-                    $self->start_work(
-                        node_id       => $pinfo->{id},
-                        start         => $start,
-                        start_comment => 'pull project',
-                        stop          => time,
-                        billable      => 0
-                    );
-
                     my $status = $client->sync_hub( $hinfo->{id} );
 
                     unless ( $status eq 'HubMatch'
@@ -178,7 +168,7 @@ bif-pull-project -  import projects from a remote hub
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
