@@ -6,7 +6,7 @@ use Bif::Sync::Client;
 use Bif::Mo;
 use Coro;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -54,6 +54,9 @@ sub run {
         eval {
             $dbw->txn(
                 sub {
+                    $self->pause_work;
+                    my $start = time;
+
                     my $msg = "[ push: $opts->{path} ($opts->{hub}) ]";
                     if ( $opts->{message} ) {
                         $msg .= "\n\n$opts->{message}\n";
@@ -72,6 +75,15 @@ sub run {
                         },
                     ) unless $re_push;
 
+                    $self->save_new_work(
+                        change_id => $opts->{change_id},
+                        node_id   => $pinfo->{id},
+                        start     => $start,
+                        stop      => time,
+                        comment   => "push project",
+                        bill      => 1,
+                    );
+
                     $self->end_change(
                         id            => $opts->{change_id},
                         action_format => "push project $pinfo->{path} "
@@ -131,6 +143,7 @@ sub run {
                     print "\n";
                     print "Project(s) exported: $opts->{path}\n";
 
+                    $self->resume_work;
                     return;
                 }
             );
@@ -161,7 +174,7 @@ bif-push-project -  export a project to a remote hub
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
