@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif::show';
 
 sub run {
@@ -32,6 +32,15 @@ sub run {
         where      => { 'n.id' => $hub->{id} },
     );
 
+    # Remove 1 from the count to account for the hub itself being a
+    # project
+    my $pcount = $db->xval(
+        select => 'COUNT(ph.project_id) - 1',
+        from   => 'project_hubs ph',
+        where  => { 'ph.hub_id' => $hub->{id} },
+    );
+    push( @data, $self->header( '  Projects', $pcount ) );
+
     $self->start_pager;
     print $self->render_table( 'l  l', [ 'Hub', $hub->{name} ], \@data, 1 );
     print "\n";
@@ -53,7 +62,7 @@ bif-show-hub - display a hub's current status
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
