@@ -7,13 +7,14 @@ use DBIx::ThinSQL qw/ sq /;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 my ( $bold, $reset );
 
 sub _build {
     my $id    = shift;
+    my $bill  = shift;
     my $count = @_;
 
     my @columns;
@@ -57,25 +58,17 @@ sub _build {
             die "unknown type: $type";
         }
 
-        push( @columns,
-                " printf('%d:%0.2d', "
-              . "   SUM(col$i) / 3600, "
-              . "   (SUM(col$i) - 3600 * (SUM(col$i) / 3600)) / 60 "
-              . " ) AS duration$i" );
-
-        push( @having, ' OR ' ) if @having;
-        push( @having, "SUM(col$i) >= 60" );
+        push( @columns, "TOTAL(col$i) AS duration$i" );
+        push( @having,  ' OR ' ) if @having;
+        push( @having,  "SUM(col$i) >= 60" );
 
         my @x;
-        my @y;
         foreach my $j ( 1 .. $count ) {
             if ( $i == $j ) {
                 push( @x, "wd.stop - wd.start AS col$j" );
-                push( @y, "wb.stop - wb.start AS col$j" );
             }
             else {
                 push( @x, "NULL AS col$j" );
-                push( @y, "NULL AS col$j" );
             }
         }
 
@@ -108,34 +101,8 @@ sub _build {
                 "where -- $start -> $end" => {
                     'wd.gtime_start >=' => $start->epoch,
                     'wd.gtime_stop <'   => $end->epoch,
+                    $bill ? ( 'wd.bill' => 1 ) : (),
                 },
-                union_all_select => [
-                    'n.kind AS kind',
-                    'n.path || " (' . "${bold}unrec$reset" . ')" AS path', @y,
-                ],
-                from                   => 'bifkv b',
-                inner_join             => 'work_buffers wb',
-                "on -- $start -> $end" => {
-                    'wb.billable'       => 1,
-                    'wb.gtime_start >=' => $start->epoch,
-                    'wb.gtime_stop <'   => $end->epoch,
-                },
-                $rollup
-                ? (
-                    inner_join => 'nodes_tree nt',
-                    on         => 'nt.child = wb.node_id',
-                    inner_join => 'projects p',
-                    on         => 'p.id = nt.parent',
-                  )
-                : (
-                    inner_join => 'nodes n2',
-                    on         => 'n2.id = wb.node_id',
-                    inner_join => 'projects p',
-                    on         => 'p.id = n2.project_id',
-                ),
-                inner_join => 'nodes n',
-                on         => 'n.id = p.id',
-                where      => { key => 'self', identity_id => $id },
             ]
         );
 
@@ -198,45 +165,58 @@ sub run {
 
     if ( $opts->{year} ) {
         $opts->{number} ||= 4;
-        ( $col, $select, $having, $format, $header ) = _build( $id,
+        ( $col, $select, $having, $format, $header ) = _build(
+            $id,
+            $opts->{bill},
             map { [ 'year', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
-              1 .. $opts->{number} );
+              1 .. $opts->{number}
+        );
     }
     elsif ( $opts->{month} ) {
         $opts->{number} ||= 4;
         ( $col, $select, $having, $format, $header ) = _build(
             $id,
+            $opts->{bill},
             map { [ 'month', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
               1 .. $opts->{number}
         );
     }
     elsif ( $opts->{week} ) {
         $opts->{number} ||= 4;
-        ( $col, $select, $having, $format, $header ) = _build( $id,
+        ( $col, $select, $having, $format, $header ) = _build(
+            $id,
+            $opts->{bill},
             map { [ 'week', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
-              1 .. $opts->{number} );
+              1 .. $opts->{number}
+        );
     }
     elsif ( $opts->{day} ) {
         $opts->{number} ||= 3;
-        ( $col, $select, $having, $format, $header ) = _build( $id,
+        ( $col, $select, $having, $format, $header ) = _build(
+            $id,
+            $opts->{bill},
             map { [ 'day', $dt, -( $opts->{number} - $_ ), $opts->{rollup} ] }
-              1 .. $opts->{number} );
+              1 .. $opts->{number}
+        );
     }
     else {
         ( $col, $select, $having, $format, $header ) = _build(
             $id,
+            $opts->{bill},
             [ 'day',   $dt, 0, $opts->{rollup} ],
             [ 'week',  $dt, 0, $opts->{rollup} ],
             [ 'month', $dt, 0, $opts->{rollup} ],
             [ 'year',  $dt, 0, $opts->{rollup} ],
         );
+        $opts->{number} = 4;
     }
 
     my @data = $db->xarrayrefs(
         select   => [ 'kind', 'path', @$col, ],
         from     => sq( map   { @$_ } @$select ),
         group_by => [qw/kind path/],
-        having   => $having,
+
+        #        having   => $having,
         order_by => 'path',
     );
 
@@ -244,6 +224,27 @@ sub run {
         print "Timesheet is empty (or < 0:01) for selected period.\n";
     }
     else {
+        my @totals = ( 'TOTAL', '-' );
+
+        foreach my $row (@data) {
+            unless ( $opts->{rollup} and $row->[1] =~ m!/! ) {
+                $totals[ 1 + $_ ] += $row->[ 1 + $_ ] for 1 .. $opts->{number};
+            }
+            $row->[ 1 + $_ ] = sprintf( '%d:%0.2d',
+                int( $row->[ 1 + $_ ] / 3600 ),
+                ( $row->[ 1 + $_ ] - 3600 * int( $row->[ 1 + $_ ] / 3600 ) ) /
+                  60 )
+              for 1 .. $opts->{number};
+        }
+
+        $totals[ 1 + $_ ] = sprintf( '%d:%0.2d',
+            int( $totals[ 1 + $_ ] / 3600 ),
+            ( $totals[ 1 + $_ ] - 3600 * int( $totals[ 1 + $_ ] / 3600 ) ) /
+              60 )
+          for 1 .. $opts->{number};
+
+        push( @data, [ '-', '', map { '' } 1 .. $opts->{number} ], \@totals );
+
         $self->start_pager;
         print $self->render_table( $format, [ qw/Type Path/, @$header ],
             \@data );
@@ -270,13 +271,13 @@ __END__
 
 =head1 NAME
 
-=for bif-doc #show
+=for bif-doc #timesheet
 
-bif-show-timesheet - display time worked per project
+bif-show-timesheet - display time billed per project
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
@@ -299,6 +300,10 @@ requested timespans are displayed.
 A date in format YYYY-MM-DD from which the first time period is
 selected. Defaults to the current day.
 
+=item --billed, -b
+
+Only count work items that were recorded as billable.
+
 =item --day, -d
 
 Display multiple daily timesheets. The default number is 3.
