@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -58,7 +58,7 @@ sub run {
         print $db->do( $opts->{statement} ) . "\n";
     }
 
-    return 'BifSQL';
+    return $self->ok('BifSQL');
 }
 
 1;
@@ -72,7 +72,7 @@ bif-sql -  run an SQL command against the database
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
