@@ -7,7 +7,7 @@ use Bif::Mo;
 use Coro;
 use DBIx::ThinSQL qw/qv/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -57,8 +57,6 @@ sub run {
             eval {
                 $dbw->txn(
                     sub {
-                        my $start = time;
-
                         my @status = $client->sync_hub( $hub->{id} );
 
                         unless ( $status[0] eq 'HubMatch'
@@ -135,14 +133,6 @@ sub run {
                             from => 'changes c',
                         );
 
-                        $self->start_work(
-                            node_id       => $hub->{id},
-                            start         => $start,
-                            start_comment => 'sync',
-                            stop          => time,
-                            billable      => 0,
-                        );
-
                         return;
                     }
                 );
@@ -182,7 +172,7 @@ bif-sync -  exchange changes with hubs
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
