@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -17,13 +17,8 @@ sub run {
 
     $dbw->txn(
         sub {
-            $self->start_work(
-                node_id       => $info->{id},
-                start         => time,
-                start_comment => "update identity",
-                billable      => 1,
-                save          => 1,
-            );
+            $self->pause_work;
+            my $start = time;
 
             if ( $opts->{reply} ) {
                 my $uinfo =
@@ -49,14 +44,12 @@ sub run {
                 },
             );
 
-            $self->stop_work(
-                stop    => time,
-                restore => 1,
-            );
-
-            $self->record_work(
+            $self->save_new_work(
+                change_id => $opts->{change_id},
                 node_id   => $info->{id},
-                change_id => $opts->{change_id}
+                start     => $start,
+                stop      => time,
+                bill      => 1,
             );
 
             $self->end_change(
@@ -66,6 +59,7 @@ sub run {
                 action_node_id_1 => $info->{id},
             );
 
+            $self->resume_work;
         }
     );
 
@@ -83,7 +77,7 @@ bif-update-identity - update or comment an identity
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
