@@ -5,7 +5,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/sq qv/;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -15,17 +15,12 @@ sub run {
 
     $dbw->txn(
         sub {
+            $self->pause_work;
+            my $start = time;
+
             my $info =
               $self->get_project( $opts->{id} ? $opts->{id} : $opts->{path} );
 
-            $self->start_work(
-                node_id       => $info->{id},
-                start         => time,
-                start_comment => "update project",
-                billable      => 1,
-                save          => 1,
-            );
-
             my ( $status_ids, $invalid );
             if ( $opts->{status} ) {
 
@@ -62,14 +57,12 @@ sub run {
                 }
             );
 
-            $self->stop_work(
-                stop    => time,
-                restore => 1,
-            );
-
-            $self->record_work(
-                node_id   => $info->{id},
+            $self->save_new_work(
                 change_id => $opts->{change_id},
+                node_id   => $info->{id},
+                start     => $start,
+                stop      => time,
+                bill      => 1,
             );
 
             $self->end_change(
@@ -79,6 +72,7 @@ sub run {
                 message          => $opts->{message},
             );
 
+            $self->resume_work;
         }
     );
 
@@ -96,7 +90,7 @@ bif-update-project - update a project
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
