@@ -6,7 +6,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/case coalesce sq qv/;
 use Text::FormatTable;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -39,17 +39,17 @@ sub work_log_long {
     my $sth = $db->xprepare(
         with => 'src',
         as   => sq(
-            select => [ 'wb.id AS id', 'wb.stop - wb.start AS delta', ],
-            from   => 'work_buffers wb',
+            select => [ 'wd.id AS id', 'wd.stop - wd.start AS delta', ],
+            from   => 'work_deltas wd',
         ),
         select => [
-            'wb.node_id',
+            'c.action AS action',
+            'wd.node_id',
             q{strftime('%Y-%m-%d %H:%M:%S', }
-              . q{ wb.gtime_start, 'unixepoch') AS start},
-            q{wb.start_comment AS start_comment},
+              . q{ wd.gtime_start, 'unixepoch') AS start},
+            q{wd.comment AS comment},
             q{strftime('%Y-%m-%d %H:%M:%S', }
-              . q{ wb.gtime_stop, 'unixepoch') AS stop},
-            q{wb.stop_comment AS stop_comment},
+              . q{ wd.gtime_stop, 'unixepoch') AS stop},
             q{ printf('%+0.2d:%0.2d:%0.2d', }
               . q{ src.delta / 3600, }
               . q{ (src.delta - 3600 * (src.delta / 3600)) / 60, }
@@ -57,11 +57,13 @@ sub work_log_long {
             q{COALESCE(printf('%s %s [%s]', n.kind, n.id, n.path),'') AS path},
         ],
         from       => 'src',
-        inner_join => 'work_buffers wb',
-        on         => 'wb.id = src.id',
+        inner_join => 'work_deltas wd',
+        on         => 'wd.id = src.id',
+        inner_join => 'changes c',
+        on         => 'c.id = wd.change_id',
         left_join  => 'nodes n',
-        on         => 'n.id = wb.node_id',
-        order_by   => 'wb.id DESC',
+        on         => 'n.id = wd.node_id',
+        order_by   => 'wd.id DESC',
     );
     $sth->execute;
 
@@ -72,14 +74,12 @@ sub work_log_long {
     while ( my $ref = $sth->hashref ) {
         my $table = Text::FormatTable->new(' l  l');
 
-        $table->row( $yellow . 'Work:', $ref->{path} . $reset );
-        $table->row( 'Start:',          $ref->{start} );
-        $table->row( 'Stop:',           $ref->{stop} );
-        $table->row( 'Delta:',          $ref->{delta} );
-        $table->row( 'StartComment:',   $ref->{start_comment} )
-          if $ref->{start_comment};
-        $table->row( 'StopComment:', $ref->{stop_comment} )
-          if $ref->{stop_comment};
+        $table->row( $yellow . 'Action:', $ref->{action} . $reset );
+        $table->row( 'Start:',            $ref->{start} );
+        $table->row( 'Stop:',             $ref->{stop} );
+        $table->row( 'Delta:',            $ref->{delta} );
+        $table->row( 'Comment:',          $ref->{comment} )
+          if $ref->{comment};
 
         print $table->render, "\n";
     }
@@ -99,26 +99,21 @@ sub work_log_short {
 
             # Grab stuff from the work_buffers table
             select => [
-                'wb.gtime_start AS start',
+                'wb.start + wb.offset AS start',
                 q{strftime('%Y-%m-%d', }
-                  . q{ wb.gtime_start, 'unixepoch') AS start_ymd},
-                'wb.gtime_stop AS stop',
-                'wb.stop - wb.start AS delta',
+                  . q{ wb.start+wb.offset, 'unixepoch') AS start_ymd},
+                "strftime('%s','now') AS stop",
+                "strftime('%s','now') - wb.start AS delta",
                 'n.id AS id',
                 'i.shortname AS shortname',
-                'COALESCE(n.path,"-") AS path',
-                q{COALESCE(wb.start_comment || ', ' || wb.stop_comment,}
-                  . q{wb.start_comment, wb.stop_comment, '-') AS comment},
-                'wb.billable AS billable',
-                case (
-                    when => 'wb.billable',
-                    then => qv("(${bold}unrec$reset)"),
-                    else => "'-'",
-                )->as('change_id'),
+                "'work ' || n.kind || ' ' || n.path "
+                  . "|| COALESCE(' -- '|| wb.comment, '') AS action",
+                'wb.bill AS bill',
+                "'-' AS change_id",
             ],
-            from      => 'work_buffers wb',
-            left_join => 'nodes n',
-            on        => 'n.id = wb.node_id',
+            from       => 'work_buffers wb',
+            inner_join => 'nodes n',
+            on         => 'n.id = wb.node_id',
             $identity_id
             ? (
                 inner_join => 'identities i',
@@ -140,10 +135,8 @@ sub work_log_short {
                 'wd.stop - wd.start AS delta',
                 'n.id AS id',
                 'i.shortname AS shortname',
-                'n.path AS path',
-                q{COALESCE(wd.start_comment || ', ' || wd.stop_comment,}
-                  . q{wd.start_comment, wd.stop_comment, '-') AS comment},
-                '0 AS billable',
+                "c.action || COALESCE(' -- '|| wd.comment, '') AS action",
+                '0 AS bill',
                 'wd.change_id AS change_id',
             ],
             from       => 'work_deltas wd',
@@ -163,6 +156,7 @@ sub work_log_short {
         as  => sq(
             select => [
                 'w.start_ymd AS start_ymd',
+                'MAX(w.start) AS max_start',
                 'SUM(w.delta) AS delta',
                 "julianday(date('now','localtime'))"
                   . " - julianday(w.start_ymd) AS day"
@@ -185,9 +179,8 @@ sub work_log_short {
               AS delta_hm },
             'w.shortname AS shortname',
             'w.id AS id',
-            'w.path AS path',
-            'w.comment AS comment',
-            'w.billable AS billable',
+            'w.action AS action',
+            'w.bill AS bill',
             'w.change_id AS change_id',
         ],
         from => 'worked w',
@@ -195,7 +188,7 @@ sub work_log_short {
         # total/summary row
         union_all_select => [
             'ws.start_ymd AS start_ymd',
-            '-1 AS start',
+            'ws.max_start + 1 AS start',
             '-1 AS start_hm',
             '-1 AS stop',
             '-1 AS stop_hm',
@@ -205,21 +198,22 @@ sub work_log_short {
               . q{ 3600 * round(ws.delta / 3600)) / 60) AS delta_hm},
             '-1 AS shortname',
             'NULL AS id',
-            'NULL AS path',
-            'ws.day AS comment',
-            'NULL AS billable',
+            'ws.day AS action',
+            'NULL AS bill',
             'NULL AS change_id',
         ],
         from     => 'worked_summary ws',
-        order_by => [ 'start_ymd DESC', 'start ASC', 'stop ASC' ]
+        order_by => [ 'start_ymd DESC', 'start DESC', 'stop DESC' ]
     );
 
     $sth->execute;
+
+    #    $sth->dump_results;
     $self->start_pager;
 
     my $i      = 0;
-    my $format = ' l  l  l  r  r ';
-    my @empty  = ( '-', '', '', '', '' );
+    my $format = ' l  l  l  r ';
+    my @empty  = ( '-', '', '', '' );
     my $table  = Text::FormatTable->new($format);
     my $first  = 1;
 
@@ -239,10 +233,9 @@ sub work_log_short {
 
             $table->head(
                 $yellow . $ref->{start_ymd},
-                0 == $ref->{comment}   ? 'Activity [today]'
-                : 1 == $ref->{comment} ? 'Activity [yesterday]'
-                : "Activity [$ref->{comment} days ago]",
-                'Topic',
+                0 == $ref->{action}   ? 'Activity [today]'
+                : 1 == $ref->{action} ? 'Activity [yesterday]'
+                : "Activity [$ref->{action} days ago]",
                 'CID',
                 $ref->{delta_hm} . $reset
             );
@@ -250,10 +243,9 @@ sub work_log_short {
         }
         else {
             $table->row(
-                ( $ref->{stop_hm} ? '' : $bold )
+                ( $ref->{change_id} eq '-' ? $bold : '' )
                 . "$ref->{start_hm} - $ref->{stop_hm}",
-                $ref->{comment},
-                $ref->{path},
+                $ref->{action},
                 $ref->{change_id},
                 $ref->{delta_hm} . $reset,
 
@@ -273,13 +265,13 @@ __END__
 
 =head1 NAME
 
-=for bif-doc #log
+=for bif-doc #timesheet
 
 bif-wlog - review work buffer entries
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
