@@ -6,7 +6,7 @@ use DBIx::ThinSQL qw/concat coalesce qv/;
 use IO::Prompt::Tiny qw/prompt/;
 use Time::Piece;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 extends 'App::bif';
 
 sub run {
@@ -40,67 +40,75 @@ sub run {
 
     my $epoch = $self->datetime2s( $opts->{at} );
 
-    # Stop work
-    if ( $opts->{id} eq '-' ) {
+    return $dbw->txn(
+        sub {
+            # Stop work if we were actually working
+            if ($work) {
+                $self->stop_work(
+                    bill    => $opts->{bill},
+                    stop    => $epoch,
+                    comment => $opts->{comment},
+                );
 
-        # But only if we were actually working
-        if ($work) {
-            $self->stop_work(
-                stop         => $epoch,
-                stop_comment => $opts->{comment},
+                printf "stopped working %s %s after %s\n", $work->{kind},
+                  $work->{path},
+                  $self->s2hm( $epoch - $work->{start} );
+                return $self->ok('StopWork') if $opts->{id} eq '-';
+            }
+
+            if ( $opts->{id} eq '-' ) {
+
+                print "Not currently working a node.\n";
+                return $self->ok('NoWork');
+            }
+
+            # Check validity of ID
+            my $info = $self->get_node( $opts->{id} );
+            $opts->{id} = $info->{id};
+
+            # Maybe complain if we are working something else
+            if ($work) {
+                return $self->err(
+                    'WorkOther',   "working %s %s [%s] since %s",
+                    $work->{kind}, $work->{node_id},
+                    $work->{path}, scalar localtime( $work->{start} )
+                ) unless $opts->{force};
+
+                $opts->{comment} ||= prompt( 'Comment:', '' );
+                $self->stop_work( stop => $epoch - 1 );
+                printf "stopped working %s %s after %s\n", $work->{kind},
+                  $work->{path},
+                  $self->s2hm( $epoch - $work->{start} );
+            }
+            else {
+                $opts->{comment} ||= prompt( 'Comment:', '' );
+            }
+
+            # Finally, start the new work
+
+            $self->start_work(
+                node_id => $info->{id},
+                start   => $epoch,
+                comment => $opts->{comment},
+                bill    => $opts->{bill},
             );
-            printf "stopped working %s %s after %s\n", $work->{kind},
+
+            $work = $self->current_work;
+
+            printf "working %s %s since %s\n", $work->{kind},
               $work->{path},
-              $self->s2hm( $epoch - $work->{start} );
-            return $self->ok('StopWork');
+              scalar localtime( $work->{start} );
+
+            return $self->ok('StartWork');
         }
-
-        print "Not currently working a node.\n";
-        return $self->ok('NoWork');
-    }
-
-    # Check validity of ID
-    my $info = $self->get_node( $opts->{id} );
-    $opts->{id} = $info->{id};
-
-    # Maybe complain if we are working something else
-    if ($work) {
-        return $self->err( 'WorkOther', "working %s %s [%s] since %s",
-            $work->{kind}, $work->{node_id}, $work->{path},
-            scalar localtime( $work->{start} ) )
-          unless $opts->{force};
-
-        $opts->{comment} ||= prompt( 'Comment:', '' );
-        $self->stop_work( stop => $epoch - 1 );
-        printf "stopped working %s %s after %s\n", $work->{kind},
-          $work->{path},
-          $self->s2hm( $epoch - $work->{start} );
-    }
-    else {
-        $opts->{comment} ||= prompt( 'Comment:', '' );
-    }
-
-    # Finally, start the new work
-    $self->start_work(
-        node_id       => $info->{id},
-        start         => $epoch,
-        start_comment => $opts->{comment},
-        billable      => $opts->{not_billable} ? 0 : 1,
     );
 
-    $work = $self->current_work;
-
-    printf "working %s %s since %s\n", $work->{kind},
-      $work->{path},
-      scalar localtime( $work->{start} );
-
-    return $self->ok('StartWork');
 }
 
 1;
 __END__
 
-=for bif-doc #modify
+=for bif-doc #timesheet
 
 =head1 NAME
 
@@ -108,7 +116,7 @@ bif-work - track your work on a node
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
@@ -152,7 +160,7 @@ accept the string "yesterday" in place of "yyyy-mm-dd".
 
 Force the working of a node even when currently working.
 
-=item --not-billable, -B
+=item --not-bill, -B
 
 Do not record this work entry in the next update.
 
