@@ -3,12 +3,13 @@ use strict;
 use warnings;
 use DBIx::ThinSQL qw/case qv/;
 
-our $VERSION = '0.1.5_6';
+our $VERSION = '0.1.5_7';
 
 our %statements = (
     new_hub => [
         select => [
             '"new_hub" AS _delta',
+            'n.bill AS bill',
             'hd.location AS location',
             'n.uuid AS uuid',
         ],
@@ -33,39 +34,10 @@ our %statements = (
         where      => 'pd.id = ?',
     ],
 
-    new_hub_repo => [
-        select => [
-            '"new_hub_repo" AS _delta',
-            'h.uuid AS hub_uuid',
-            'hrd.location AS location',
-            'hr.uuid AS uuid',
-        ],
-        from       => 'hub_repo_deltas hrd',
-        inner_join => 'nodes hr',
-        on         => 'hr.id = hrd.hub_repo_id',
-        left_join  => 'nodes h',
-        on         => 'h.id = hrd.hub_id',
-        where      => 'hrd.id = ?',
-    ],
-
-    update_hub_repo => [
-        select => [
-            '"update_hub_repo" AS _delta',
-            'h.uuid AS hub_uuid',    # should never change, remove?
-            'hrd.location AS location',
-            'hr.uuid AS uuid',
-        ],
-        from       => 'hub_repo_deltas hrd',
-        inner_join => 'nodes hr',
-        on         => 'hr.id = hrd.hub_repo_id',
-        left_join  => 'nodes h',
-        on         => 'h.id = hrd.hub_id',
-        where      => 'hrd.id = ?',
-    ],
-
     new_identity => [
         select => [
             '"new_identity" AS _delta',
+            'i.bill AS bill',
             'ed.name AS name',
             'id.shortname AS shortname',
             'con.uuid AS contact_uuid',
@@ -108,6 +80,7 @@ our %statements = (
     new_identity_contact_method => [
         select => [
             '"new_identity_contact_method" AS _delta',
+            'ecmn.bill AS bill',
             'i.uuid AS identity_uuid',
             'ecmd.method AS method',
             'ecmd.mvalue AS mvalue',
@@ -138,6 +111,7 @@ our %statements = (
     new_project => [
         select => [
             '"new_project" AS _delta',
+            'p.bill AS bill',
             'nd.name AS name',
             'pp.uuid AS parent_uuid',
             'pd.title AS title',
@@ -180,6 +154,7 @@ our %statements = (
     new_project_status => [
         select => [
             '"new_project_status" AS _delta',
+            'n.bill AS bill',
             'p.uuid AS project_uuid',
             'psd.rank AS rank',
             'psd.status AS status',
@@ -219,6 +194,7 @@ our %statements = (
     new_topic => [
         select => [
             '"new_topic" AS _delta',
+            'n.bill AS bill',
             'ts.uuid AS topic_status_uuid',
             'lt.uuid AS link_topic_uuid',
             'ltd.title AS title',
@@ -258,6 +234,7 @@ our %statements = (
     new_topic_status => [
         select => [
             '"new_topic_status" AS _delta',
+            'n.bill AS bill',
             'tsd.def AS def',
             'p.uuid AS project_uuid',
             'ts.tkind AS tkind',
@@ -292,11 +269,11 @@ our %statements = (
     new_work => [
         select => [
             '"new_work" AS _delta',
+            'wd.bill AS bill',
             'wd.offset AS offset',
             'wd.start AS start',
             'wd.stop AS stop',
-            'wd.start_comment AS start_comment',
-            'wd.stop_comment AS stop_comment',
+            'wd.comment AS comment',
             'n.uuid AS node_uuid',
         ],
         from       => 'work_deltas wd',
@@ -389,7 +366,6 @@ sub Bif::DB::db::uchangeset_v1 {
 
 our %import = (
     new_hub                     => 'func_import_new_hub',
-    new_hub_repo                => 'func_import_new_hub_repo',
     new_identity_contact_method => 'func_import_new_identity_contact_method',
     new_identity                => 'func_import_new_identity',
     new_project                 => 'func_import_new_project',
@@ -399,7 +375,6 @@ our %import = (
     new_topic_status            => 'func_import_new_topic_status',
     new_work                    => 'func_import_new_work',
     update_hub                  => 'func_import_update_hub',
-    update_hub_repo             => 'func_import_update_hub_repo',
     update_identity_contact_method =>
       'func_import_update_identity_contact_method',
     update_identity => 'func_import_update_identity',
@@ -485,7 +460,7 @@ database
 
 =head1 VERSION
 
-0.1.5_6 (2015-10-20)
+0.1.5_7 (2015-11-25)
 
 =head1 SYNOPSIS
 
