@@ -6,6 +6,7 @@ CREATE TABLE func_import_begin_change(
     author_shortname VARCHAR(255),
     lang VARCHAR(8) NOT NULL,
     mtime INTEGER NOT NULL,
+    mtimef INTEGER NOT NULL,
     mtimetz INTEGER NOT NULL
 );
 
@@ -24,6 +25,7 @@ BEGIN
         NEW.author_contact_method,
         NEW.author_shortname,
         NEW.mtime,
+        NEW.mtimef,
         NEW.mtimetz,
         NEW.lang
     );
@@ -37,6 +39,7 @@ BEGIN
             author_contact_method,
             author_shortname,
             mtime,
+            mtimef,
             mtimetz,
             lang
         )
@@ -48,6 +51,7 @@ BEGIN
         NEW.author_contact_method,
         NEW.author_shortname,
         NEW.mtime,
+        NEW.mtimef,
         NEW.mtimetz,
         NEW.lang
     FROM
