@@ -1,7 +1,7 @@
 CREATE TABLE func_import_end_change(
     action_format VARCHAR NOT NULL,
-    action_topic_uuid_1 VARCHAR(40),
-    action_topic_uuid_2 VARCHAR(40),
+    action_node_uuid_1 VARCHAR(40),
+    action_node_uuid_2 VARCHAR(40),
     identity_uuid VARCHAR(40),
     message VARCHAR,
     uuid VARCHAR(40)
@@ -16,8 +16,8 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        NEW.action_topic_uuid_1,
-        NEW.action_topic_uuid_2,
+        NEW.action_node_uuid_1,
+        NEW.action_node_uuid_2,
         NEW.identity_uuid,
         NEW.message,
         NEW.uuid
@@ -27,8 +27,8 @@ BEGIN
         func_end_change(
             id,
             action_format,
-            action_topic_id_1,
-            action_topic_id_2,
+            action_node_id_1,
+            action_node_id_2,
             identity_id,
             message,
             uuid
@@ -36,21 +36,21 @@ BEGIN
     SELECT
         currval('changes'),
         NEW.action_format,
-        t1.id,
-        t2.id,
+        n1.id,
+        n2.id,
         i.id,
         NEW.message,
         NEW.uuid
     FROM
-        topics i
+        nodes i
     LEFT JOIN
-        topics t1
+        nodes n1
     ON
-        t1.uuid = NEW.action_topic_uuid_1
+        n1.uuid = NEW.action_node_uuid_1
     LEFT JOIN
-        topics t2
+        nodes n2
     ON
-        t2.uuid = NEW.action_topic_uuid_2
+        n2.uuid = NEW.action_node_uuid_2
     WHERE
         i.uuid = NEW.identity_uuid
     ;
