@@ -3,7 +3,8 @@ CREATE TABLE func_import_new_entity(
     node_uuid VARCHAR(40) NOT NULL,
     contact_uuid VARCHAR(40),
     default_contact_method_uuid VARCHAR(40),
-    name VARCHAR NOT NULL
+    name VARCHAR NOT NULL,
+    bill BOOL NOT NULL
 );
 
 CREATE TRIGGER
@@ -18,7 +19,8 @@ BEGIN
         NEW.node_uuid,
         NEW.contact_uuid,
         NEW.default_contact_method_uuid,
-        NEW.name
+        NEW.name,
+        NEW.bill
     );
 
     INSERT INTO
@@ -27,14 +29,16 @@ BEGIN
             id,
             contact_id,
             default_contact_method_id,
-            name
+            name,
+            bill
         )
     SELECT
         c.id,
         n.id,
         cn.id,
         ecm.id,
-        NEW.name
+        NEW.name,
+        NEW.bill
     FROM
         changes c
     INNER JOIN
