@@ -73,7 +73,7 @@ sub _bif {
 
     if ( !$VERBOSE ) {
         open( $stdout, '>&', 'STDOUT' )     or die "open: $!";
-        open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
+        open( STDOUT,  '>',  'stdoun.txt' ) or die "open: $!";
     }
 
     Test::More::note( sprintf( $str, "bif @bif" ) );
@@ -87,7 +87,7 @@ sub _bif {
     if ( !$VERBOSE ) {
         open( STDOUT, '>&', $stdout );
         close $stdout;
-        unlink 'stdout.txt';
+        unlink 'stdoun.txt';
     }
 
     die $err if $err;
@@ -125,7 +125,7 @@ sub bifsync {
 
     if ( !$VERBOSE ) {
         open( $stdout, '>&', 'STDOUT' )     or die "open: $!";
-        open( STDOUT,  '>',  'stdout.txt' ) or die "open: $!";
+        open( STDOUT,  '>',  'stdoun.txt' ) or die "open: $!";
     }
 
     Test::More::note("bifsync @_");
@@ -139,7 +139,7 @@ sub bifsync {
     if ( !$VERBOSE ) {
         open( STDOUT, '>&', $stdout );
         close $stdout;
-        unlink 'stdout.txt';
+        unlink 'stdoun.txt';
     }
 
     die $err if $err;
@@ -184,8 +184,8 @@ sub new_test_hub {
     my $local  = shift;
     my $change = new_test_change($db);
 
-    my $id  = $db->nextval('topics');
-    my $lid = $db->nextval('topics');
+    my $id  = $db->nextval('nodes');
+    my $lid = $db->nextval('nodes');
 
     my $ref = {
         id        => $id,
@@ -195,7 +195,7 @@ sub new_test_hub {
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change->{id},
             id        => $id,
@@ -245,7 +245,7 @@ my $project = 0;
 sub new_test_project {
     my $db        = shift;
     my $change_id = shift || $db->currval('changes');
-    my $id        = $db->nextval('topics');
+    my $id        = $db->nextval('nodes');
 
     $project++;
 
@@ -257,7 +257,7 @@ sub new_test_project {
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change_id,
             id        => $id,
@@ -285,7 +285,7 @@ sub new_test_project_status {
     my $db        = shift;
     my $project   = shift;
     my $change_id = shift || $db->currval('changes');
-    my $id        = $db->nextval('topics');
+    my $id        = $db->nextval('nodes');
 
     $project_status++;
 
@@ -298,7 +298,7 @@ sub new_test_project_status {
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change_id,
             id        => $id,
@@ -320,7 +320,7 @@ sub new_test_task_status {
     my $db        = shift;
     my $project   = shift;
     my $change_id = shift || $db->currval('changes');
-    my $id        = $db->nextval('topics');
+    my $id        = $db->nextval('nodes');
 
     $task_status++;
 
@@ -334,7 +334,7 @@ sub new_test_task_status {
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change_id,
             id        => $id,
@@ -356,7 +356,7 @@ sub new_test_issue_status {
     my $db        = shift;
     my $project   = shift;
     my $change_id = shift || $db->currval('changes');
-    my $id        = $db->nextval('topics');
+    my $id        = $db->nextval('nodes');
 
     $issue_status++;
 
@@ -370,7 +370,7 @@ sub new_test_issue_status {
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change_id,
             id        => $id,
@@ -393,7 +393,7 @@ sub new_test_task {
     my $db        = shift;
     my $status    = shift;
     my $change_id = shift || $db->currval('changes');
-    my $id        = $db->nextval('topics');
+    my $id        = $db->nextval('nodes');
 
     $task++;
 
@@ -405,7 +405,7 @@ sub new_test_task {
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change_id,
             id        => $id,
@@ -428,24 +428,24 @@ sub new_test_issue {
     my $db        = shift;
     my $status    = shift;
     my $change_id = shift || $db->currval('changes');
-    my $id        = $db->nextval('topics');
-    my $topic_id  = $db->nextval('topics');
+    my $id        = $db->nextval('nodes');
+    my $node_id   = $db->nextval('nodes');
 
     $issue++;
 
     my $ref = {
         change_id => $change_id,
         id        => $id,
-        topic_id  => $topic_id,
+        node_id   => $node_id,
         title     => 'title' . $issue,
         status_id => $status->{id},
     };
 
     $db->xdo(
-        insert_into => 'func_new_topic',
+        insert_into => 'func_new_node',
         values      => {
             change_id => $change_id,
-            id        => $topic_id,
+            id        => $node_id,
             kind      => 'issue',
         },
     );
